@@ -7,9 +7,9 @@ from _plotly_utils.utils import PlotlyJSONEncoder
 from .jupyter import register_jupyter
 from .string import task_string_to_context
 
-__author__ = """Brad Johnson"""
-__email__ = "brad.johnson@twinthread.com"
-__version__ = 0.8.9"
+__author__ = """Brent Baumgartner"""
+__email__ = "brent@twinthread.com"
+__version__ = "0.4.0"
 
 import re
 import json
